Processor.App.OutStreamer.outstreamer.OutStreamer
=================================================

.. currentmodule:: Processor.App.OutStreamer.outstreamer

.. autoclass:: OutStreamer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~OutStreamer.__init__
      ~OutStreamer.clean_up
      ~OutStreamer.stream
   
   

   
   
   